"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const parse_1 = __importDefault(require("../formatter/parse/parse"));
/**
 * @example
 * ```javascript
 * parse('1,250.48')
 * //=> 1250.48
 * parse('10 %')
 * //=> 0.1
 * parse('1 000,582', { locale: fr })
 * //=> 1000.582
 * ```
 * Parse the given numeric-string applying the provided options.
 *
 * options:
 * ```typescript
 * {
 * nullFormat?: string;
 * nanFormat?: string;
 * zeroFormat?: string;
 * defaultPattern?: string;
 * rounding?: 'truncate' | 'ceil' | 'floor' | 'round' | ((scaledValueForRounding: number) => number);
 * locale?: NumerableLocale;
 * type?: string;
 * scalePercentage?: boolean;
 * formatters?: NumerableFormatter[] | ((builtInFormatters: NumerableFormatter[]) => NumerableFormatter[]);
 * }
 * ```
 *
 * @param string string: The numeric-string to parse (e.g. **'10 %'**)
 * @param options options: The options used to parse the numeric-string
 * ```typescript
 * {
 * nullFormat?: string;
 * nanFormat?: string;
 * zeroFormat?: string;
 * defaultPattern?: string;
 * rounding?: 'truncate' | 'ceil' | 'floor' | 'round' | ((scaledValueForRounding: number) => number);
 * locale?: NumerableLocale;
 * type?: string;
 * scalePercentage?: boolean;
 * formatters?: NumerableFormatter[] | ((builtInFormatters: NumerableFormatter[]) => NumerableFormatter[]);
 * }
 * ```
 */
const parse = (string, options) => {
    return parse_1.default(string, options);
};
exports.default = parse;
//# sourceMappingURL=parse.js.map