"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const round_number_1 = __importDefault(require("../core/utils/round-number"));
/**
 * @example
 * ```javascript
 * round(12.687, 2)
 * //=> 12.69
 * round(12.687)
 * //=> 13
 * round(12.687, 2, Math.floor)
 * //=> 12.68
 * ```
 * Rounds the given number to the specified amount of decimal places.
 *
 * - The **default precision** is 0.
 * - The **default roundingFunction** is Math.round.
 *
 * @param number number: The number to round (e.g. **10.23**)
 * @param precision precision: The desired amount of decimal places (e.g. **2**)
 * @param roundingFunction roundingFunction: The function applied for rounding (e.g. **Math.floor**)
 * */
const round = (number, precision, roundingFunction) => {
    return round_number_1.default(number, precision, roundingFunction);
};
exports.default = round;
//# sourceMappingURL=round.js.map