"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const round_number_1 = __importDefault(require("./round-number"));
const string_repeat_1 = __importDefault(require("./string-repeat"));
const split_string_in_two_parts_1 = __importDefault(require("./split-string-in-two-parts"));
const number_to_non_exponential_string_1 = __importDefault(require("./number-to-non-exponential-string"));
const addTrailingZerosInFractionalPart = (valueAsString, minimumFractionDigits) => {
    const [integerPart, fractionalPart] = split_string_in_two_parts_1.default(valueAsString, '.');
    return `${integerPart}.${fractionalPart + string_repeat_1.default('0', minimumFractionDigits - fractionalPart.length)}`;
};
/**
 * Implementation of Number.prototype.toFixed() that treats floats more like decimals
 *
 * Fixes binary rounding issues (eg. (0.615).toFixed(2) === '0.61') that present
 * problems for accounting- and finance-related software.
 *
 * <!> This function should only receive a finite number, never NaN, Infinity or -Infinity
 * <i> This function should return always a JS string representation of a number, but without exponent.
 * <i> optionalFractionDigits means: from the fractionDigits amount, the ones that are optional.
 */
const numberToFixed = (finiteNumber, fractionDigits, roundingFunction, optionalFractionDigits) => {
    const valueAsString = number_to_non_exponential_string_1.default(finiteNumber);
    const minimumFractionDigits = fractionDigits - (optionalFractionDigits || 0);
    const fractionalPartOfValueAsString = split_string_in_two_parts_1.default(valueAsString, '.')[1];
    const targetFractionDigitsAmount = !!fractionalPartOfValueAsString
        ? Math.min(Math.max(fractionalPartOfValueAsString.length, minimumFractionDigits), fractionDigits)
        : minimumFractionDigits;
    const roundedValue = round_number_1.default(finiteNumber, targetFractionDigitsAmount, roundingFunction);
    let output = number_to_non_exponential_string_1.default(roundedValue);
    // Add trailing zeros if needed
    if (!!minimumFractionDigits) {
        output = addTrailingZerosInFractionalPart(output, minimumFractionDigits);
    }
    return output;
};
exports.default = numberToFixed;
//# sourceMappingURL=number-to-fixed.js.map