"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.unitScale = exports.toBest = exports.convertUnit = exports.toBase = void 0;
const log_10_1 = __importDefault(require("./log-10"));
const is_power_of_ten_1 = __importDefault(require("./is-power-of-ten"));
const is_finite_number_1 = __importDefault(require("./is-finite-number"));
const multiply_by_power_of_ten_1 = __importDefault(require("./multiply-by-power-of-ten"));
const toBase = (value, valueUnit, unitScale) => {
    if (!is_finite_number_1.default(value) || valueUnit === unitScale.base)
        return value;
    if (!(valueUnit in unitScale.scale))
        return NaN;
    const toBaseMultiplier = unitScale.scale[valueUnit] || 1;
    return is_power_of_ten_1.default(toBaseMultiplier)
        ? multiply_by_power_of_ten_1.default(value, log_10_1.default(toBaseMultiplier))
        : value * toBaseMultiplier;
};
exports.toBase = toBase;
const convertUnit = (value, originUnit, targetUnit, unitScale) => {
    if (!is_finite_number_1.default(value) || originUnit === targetUnit)
        return value;
    const valueAsBase = exports.toBase(value, originUnit, unitScale);
    const resolvedScale = Object.assign(Object.assign({}, unitScale.scale), { [unitScale.base]: 1 });
    if (isNaN(valueAsBase) || !(originUnit in resolvedScale) || !(targetUnit in resolvedScale))
        return NaN;
    const conversionFactorFromBase = unitScale.scale[targetUnit] || 1;
    return is_power_of_ten_1.default(conversionFactorFromBase)
        ? multiply_by_power_of_ten_1.default(valueAsBase, -log_10_1.default(conversionFactorFromBase))
        : valueAsBase / conversionFactorFromBase;
};
exports.convertUnit = convertUnit;
/**
 * Looks through every possibility for the 'best' available unit.
 * i.e. Where the value has the fewest numbers before the decimal point,
 * but is still higher than 1.
 */
const toBest = (value, originUnit, unitScale, options) => {
    const resolvedOptions = Object.assign({ exclude: [], cutOffNumber: 1 }, options);
    let best = null;
    const scale = unitScale.scale;
    Object.keys(scale).sort((a, b) => scale[a] - scale[b]).forEach((scaleUnit) => {
        const isIncluded = resolvedOptions.exclude.indexOf(scaleUnit) === -1;
        if (!isIncluded)
            return;
        const result = exports.convertUnit(value, originUnit, scaleUnit, unitScale);
        const absoluteResult = Math.abs(result);
        if (!best || (absoluteResult >= resolvedOptions.cutOffNumber && absoluteResult < Math.abs(best[0]))) {
            best = [result, scaleUnit];
        }
    });
    return best || [value, originUnit];
};
exports.toBest = toBest;
const unitScale = (unitScaleDefinition) => {
    return {
        toBase: (value, unit) => {
            return exports.toBase(value, unit, unitScaleDefinition);
        },
        convert: (value, originUnit, targetUnit) => {
            return exports.convertUnit(value, originUnit, targetUnit, unitScaleDefinition);
        },
        toBest: (value, originUnit, options) => {
            return exports.toBest(value, originUnit, unitScaleDefinition, options);
        },
        scaleDefinition: unitScaleDefinition,
    };
};
exports.unitScale = unitScale;
//# sourceMappingURL=unit-scale.js.map