"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const is_nil_1 = __importDefault(require("../../core/utils/is-nil"));
const is_string_1 = __importDefault(require("../../core/utils/is-string"));
const is_function_1 = __importDefault(require("../../core/utils/is-function"));
const is_nan_number_1 = __importDefault(require("../../core/utils/is-nan-number"));
const pattern_regexp_utils_1 = require("../utils/pattern-regexp-utils");
const resolve_format_options_1 = __importDefault(require("../../formatter/utils/resolve-format-options"));
const number_to_formatted_number_1 = __importDefault(require("./number-to-formatted-number/number-to-formatted-number"));
const getFormatFunctionIfMatch = (pattern, resolvedOptions) => {
    const patternWithoutEscapedText = pattern_regexp_utils_1.patternRemoveEscapedText(pattern);
    for (const formatter of resolvedOptions.formatters) {
        const matcher = formatter.regexps.format;
        if (!matcher)
            continue;
        const matcherResult = is_function_1.default(matcher) ? matcher(pattern, resolvedOptions) : !!patternWithoutEscapedText.match(matcher);
        if (matcherResult)
            return formatter.format;
    }
};
const format = (value, pattern, options) => {
    var _a;
    try {
        const resolvedValue = is_string_1.default(value) ? parseFloat(value) : value;
        const resolvedOptions = resolve_format_options_1.default(options);
        const resolvedPattern = pattern || resolvedOptions.defaultPattern;
        let output;
        if (resolvedValue === Infinity || resolvedValue === -Infinity) {
            output = resolvedValue > 0 ? '∞' : '-∞';
        }
        else if (is_nan_number_1.default(resolvedValue)) {
            return is_string_1.default(resolvedOptions.nanFormat)
                ? resolvedOptions.nanFormat
                : (is_string_1.default(resolvedOptions.nullFormat) ? resolvedOptions.nullFormat : '');
        }
        else if (is_nil_1.default(resolvedValue)) {
            output = is_string_1.default(resolvedOptions.nullFormat) ? resolvedOptions.nullFormat : '';
        }
        else if (resolvedValue === 0 && is_string_1.default(resolvedOptions.zeroFormat)) {
            output = resolvedOptions.zeroFormat;
        }
        else {
            // <!> Here value should always be a number
            const resolvedValueAsNumber = resolvedValue || 0;
            const formatFunctionFromFormatters = getFormatFunctionIfMatch(resolvedPattern, resolvedOptions);
            const resolvedFormatFunction = formatFunctionFromFormatters || number_to_formatted_number_1.default;
            output = resolvedFormatFunction(resolvedValueAsNumber, resolvedPattern, resolvedOptions);
        }
        // Ensures that it always returns an string
        output = is_string_1.default(output) ? output : '';
        return resolvedOptions.trim ? output.trim() : output;
    }
    catch (_error) {
        return ((_a = options) === null || _a === void 0 ? void 0 : _a._errorFormat) || '';
    }
};
exports.default = format;
//# sourceMappingURL=format.js.map