"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const parse_pattern_1 = __importDefault(require("../parse-pattern/parse-pattern"));
const remove_sign_if_exists_1 = __importDefault(require("./utils/remove-sign-if-exists"));
const rescale_rounded_value_1 = __importDefault(require("./utils/rescale-rounded-value"));
const is_finite_number_1 = __importDefault(require("../../../core/utils/is-finite-number"));
const scale_value_with_abbreviation_1 = __importDefault(require("./utils/scale-value-with-abbreviation"));
const round_value_and_add_trailing_zeros_1 = __importDefault(require("./utils/round-value-and-add-trailing-zeros"));
const pattern_regexp_utils_1 = require("../../utils/pattern-regexp-utils");
const replace_digits_with_numeral_system_1 = __importDefault(require("./utils/replace-digits-with-numeral-system"));
const add_or_remove_leading_zeros_to_value_1 = __importDefault(require("./utils/add-or-remove-leading-zeros-to-value"));
const add_sign_info_to_full_formatted_number_1 = __importDefault(require("./utils/add-sign-info-to-full-formatted-number"));
const split_number_integer_and_decimal_parts_1 = __importDefault(require("./utils/split-number-integer-and-decimal-parts"));
const add_thousands_separator_to_value_integer_part_1 = __importDefault(require("./utils/add-thousands-separator-to-value-integer-part"));
const apply_abbreviation_localized_unit_to_pattern_mask_1 = __importDefault(require("./utils/apply-abbreviation-localized-unit-to-pattern-mask"));
const scaleAndRoundValue = (number, patternRules, options) => {
    // If it doesn't have abbreviation, just round the value and add trailing zeros
    if (!patternRules.compact) {
        const roundedValueAsString = round_value_and_add_trailing_zeros_1.default(number, patternRules, options);
        return [roundedValueAsString, null];
    }
    // If it has abbreviation, scales the value
    const [scaledValue, scaledValueLocalizedUnit] = scale_value_with_abbreviation_1.default(number, patternRules, options);
    const roundedScaledValue = +round_value_and_add_trailing_zeros_1.default(scaledValue, patternRules, options);
    const [rescaledValue, rescaledValueLocalizedUnit] = rescale_rounded_value_1.default(+roundedScaledValue, scaledValueLocalizedUnit, patternRules, options);
    const roundedRescaledValueAsStringWithTrailingZeros = round_value_and_add_trailing_zeros_1.default(rescaledValue, patternRules, options);
    return [roundedRescaledValueAsStringWithTrailingZeros, rescaledValueLocalizedUnit];
};
const numberToFormattedNumber = (number, pattern, options) => {
    var _a;
    const patternRules = parse_pattern_1.default(pattern);
    // Ensure always uses a number or default number
    const resolvedValue = is_finite_number_1.default(number) ? number : 0;
    const [valueAsString, localizedAbbreviationUnit] = scaleAndRoundValue(resolvedValue, patternRules, options);
    // Prevents potentially wrong formatting coming from this function
    if (valueAsString === 'NaN')
        return '';
    const isValueNegative = options.negativeZero ? number < 0 : +valueAsString < 0;
    const valueAsStringWithoutSign = remove_sign_if_exists_1.default(valueAsString);
    const [integerPart, decimalPart] = split_number_integer_and_decimal_parts_1.default(valueAsStringWithoutSign, patternRules);
    const valueIntegerPartWithLeadingZeros = add_or_remove_leading_zeros_to_value_1.default(integerPart, patternRules);
    const valueIntegerPartWithThousandsSeparator = add_thousands_separator_to_value_integer_part_1.default(valueIntegerPartWithLeadingZeros, patternRules, options);
    const numeralSystemFromLocale = options.locale.numeralSystem;
    const integerPartWithNumeralSystem = replace_digits_with_numeral_system_1.default(valueIntegerPartWithThousandsSeparator, numeralSystemFromLocale);
    const decimalPartWithNumeralSystem = replace_digits_with_numeral_system_1.default(decimalPart, numeralSystemFromLocale);
    const fullNumberWithNumeralSystem = (integerPartWithNumeralSystem
        + (!!decimalPartWithNumeralSystem ? (((_a = options.locale.delimiters) === null || _a === void 0 ? void 0 : _a.decimal) || '.') + decimalPartWithNumeralSystem : ''));
    // Assembling
    const patternMaskWithAbbreviation = apply_abbreviation_localized_unit_to_pattern_mask_1.default(patternRules.patternMask, localizedAbbreviationUnit, patternRules.compact);
    const patternMaskWithNumber = patternMaskWithAbbreviation.replace(`'ɵn'`, _ => `'${fullNumberWithNumeralSystem.replace(/'/g, "\\'")}'`);
    const patternMaskWithSignInfo = add_sign_info_to_full_formatted_number_1.default(patternMaskWithNumber, isValueNegative, patternRules);
    const cleanPatternMask = patternMaskWithSignInfo.replace(/'ɵ(nps|npe|s|a|n)'/g, '');
    const fullFormattedValueWithNormalizedText = pattern_regexp_utils_1.patternStripAndNormalizeEscapedText(cleanPatternMask);
    return fullFormattedValueWithNormalizedText;
};
exports.default = numberToFormattedNumber;
//# sourceMappingURL=number-to-formatted-number.js.map