"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const pattern_regexp_utils_1 = require("../../../utils/pattern-regexp-utils");
/**
 * Checks if abbreviation is wanted
 * <i> Applied only when 'a' is present.
 * <i> If 'a' is followed by 'k' | 'm' | 'b' | 't', then, it will force the abbreviation to be the specified
 *     unit. (e.g. (123456.78, '0,0.00am')  =>  '0.12M')
 */
const abbreviationRule = (patternMask) => {
    let compactUnit = null; // force abbreviation
    let compact = false;
    // If it includes 'a' means it should be abbreviated (only if at least includes 'a')
    if (pattern_regexp_utils_1.patternIncludes(patternMask, 'a')) {
        compact = true;
        const patternWithoutEscapedText = pattern_regexp_utils_1.patternRemoveEscapedText(patternMask);
        const abbreviationRegExpResult = patternWithoutEscapedText.match(/a(k|m|b|t)?/);
        compactUnit = !!abbreviationRegExpResult ? abbreviationRegExpResult[1] : null;
    }
    let outputPatternMask = patternMask;
    outputPatternMask = pattern_regexp_utils_1.patternReplace(outputPatternMask, /a(k|m|b|t)?/, `'ɵa'`);
    return [outputPatternMask, { compact, compactUnit, compactAuto: compact && !compactUnit }];
};
exports.default = abbreviationRule;
//# sourceMappingURL=abbreviation-rule.js.map