"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const string_includes_1 = __importDefault(require("../../../../core/utils/string-includes"));
const pattern_regexp_utils_1 = require("../../../utils/pattern-regexp-utils");
const split_string_in_two_parts_1 = __importDefault(require("../../../../core/utils/split-string-in-two-parts"));
const countChars = (string, char) => {
    return !string ? 0 : string.split('').filter(stringChar => stringChar === char).length;
};
/**
 * Fraction digits (decimals) count rule (minimum and maximum fraction digits)
 * <i> Optional fraction digits would go always after the forced ones
 */
const decimalPlacesRule = (patternMask) => {
    const patternWithoutEscapedText = pattern_regexp_utils_1.patternRemoveEscapedText(patternMask);
    const patternPrecisionPart = split_string_in_two_parts_1.default(patternWithoutEscapedText, '.')[1];
    let minimumFractionDigits = 0;
    let maximumFractionDigits = 0;
    if (!!patternPrecisionPart) {
        const trimmedPatternPrecisionPart = patternPrecisionPart.trim();
        if (string_includes_1.default(trimmedPatternPrecisionPart, '[')) {
            // If it contains optional fraction digits
            const patternPrecisionPartWithoutClosingBracket = trimmedPatternPrecisionPart.replace(']', '');
            // Isolates forced (left) vs optional (right) decimals
            const precisionSplitted = split_string_in_two_parts_1.default(patternPrecisionPartWithoutClosingBracket, '[');
            minimumFractionDigits = countChars(precisionSplitted[0], '0');
            maximumFractionDigits = minimumFractionDigits + countChars(precisionSplitted[1], '0');
        }
        else if (string_includes_1.default(trimmedPatternPrecisionPart, '#')) {
            // If it contains optional fraction digits marked with '#'
            minimumFractionDigits = countChars(trimmedPatternPrecisionPart.split('#')[0], '0');
            maximumFractionDigits = trimmedPatternPrecisionPart.length;
        }
        else if (string_includes_1.default(trimmedPatternPrecisionPart, 'X')) {
            // If it contains no-maximum fraction digits marked with 'X'
            minimumFractionDigits = countChars(trimmedPatternPrecisionPart.split('X')[0], '0');
            maximumFractionDigits = 500;
        }
        else {
            const fractionDigits = countChars(trimmedPatternPrecisionPart.split(' ')[0], '0');
            minimumFractionDigits = fractionDigits;
            maximumFractionDigits = fractionDigits;
        }
    }
    return { minimumFractionDigits, maximumFractionDigits };
};
exports.default = decimalPlacesRule;
//# sourceMappingURL=decimal-places-rule.js.map