"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Basis point format (BPS)
 * <i> See https://en.wikipedia.org/wiki/Basis_point
 */
const is_finite_number_1 = __importDefault(require("../../core/utils/is-finite-number"));
const pattern_regexp_utils_1 = require("../utils/pattern-regexp-utils");
const multiply_by_power_of_ten_1 = __importDefault(require("../../core/utils/multiply-by-power-of-ten"));
const formatted_string_to_number_1 = __importDefault(require("../../formatter/parse/utils/formatted-string-to-number"));
const number_to_formatted_number_1 = __importDefault(require("../../formatter/format/number-to-formatted-number/number-to-formatted-number"));
const bpsFormatter = {
    name: 'bps',
    regexps: {
        format: /BPS/,
        unformat: /BPS/,
    },
    format: (number, pattern, options) => {
        const scaledValue = multiply_by_power_of_ten_1.default(number, 4);
        const patternWithEscapedBPS = pattern_regexp_utils_1.patternReplace(pattern, /BPS/, `'ɵBPSɵ'`);
        const formatResult = number_to_formatted_number_1.default(scaledValue, patternWithEscapedBPS, options);
        return formatResult.replace('ɵBPSɵ', 'BPS');
    },
    unformat: (string, options) => {
        const number = formatted_string_to_number_1.default(string.replace(/\s?BPS/, ''), options);
        return is_finite_number_1.default(number) ? multiply_by_power_of_ten_1.default(number, -4) : number;
    },
};
exports.default = bpsFormatter;
//# sourceMappingURL=bps.js.map