"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const to_object_1 = __importDefault(require("../../core/utils/to-object"));
const unit_scale_1 = require("../../core/utils/unit-scale");
const pattern_regexp_utils_1 = require("../utils/pattern-regexp-utils");
const formatted_string_to_number_1 = __importDefault(require("../../formatter/parse/utils/formatted-string-to-number"));
const number_to_formatted_number_1 = __importDefault(require("../../formatter/format/number-to-formatted-number/number-to-formatted-number"));
const decimalSuffixes = ['B', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB'];
const binarySuffixes = ['B', 'KiB', 'MiB', 'GiB', 'TiB', 'PiB', 'EiB', 'ZiB', 'YiB'];
const allSuffixes = decimalSuffixes.concat(binarySuffixes.slice(1));
/** Avoid collision with BPS format @see formats|bps.ts */
const unformatRegex = `(${allSuffixes.join('|').replace(/B/g, 'B(?!PS)')})`;
const bytesDecimalScale = unit_scale_1.unitScale({ base: 'B', scale: to_object_1.default(decimalSuffixes, (unit, unitIndex) => [unit, Math.pow(1000, unitIndex)]) });
const bytesBinaryScale = unit_scale_1.unitScale({ base: 'B', scale: to_object_1.default(binarySuffixes, (unit, unitIndex) => [unit, Math.pow(1024, unitIndex)]) });
const bytesFormatter = {
    name: 'bytes',
    regexps: {
        format: /([0\s]b[bd])|(b[bd][0\s])/,
        unformat: (string, options) => options.type === 'bytes' ? new RegExp(unformatRegex).test(string) : false,
    },
    format: (number, pattern, options) => {
        const scale = pattern_regexp_utils_1.patternIncludes(pattern, 'bb') ? bytesBinaryScale : bytesDecimalScale;
        const [scaledValue, scaledValueUnit] = scale.toBest(number, 'B');
        const patternWithEscapedBytes = pattern_regexp_utils_1.patternReplace(pattern, /b[bd]/, `'ɵbytesɵ'`);
        const formatResult = number_to_formatted_number_1.default(scaledValue, patternWithEscapedBytes, options);
        return formatResult.replace('ɵbytesɵ', scaledValueUnit || '');
    },
    unformat: (string, options) => {
        var _a;
        const number = formatted_string_to_number_1.default(string.replace(new RegExp(unformatRegex), ''), options);
        const suffix = ((_a = string.match(unformatRegex)) === null || _a === void 0 ? void 0 : _a[0]) || '';
        const scale = !!bytesBinaryScale.scaleDefinition.scale[suffix] ? bytesBinaryScale : bytesDecimalScale;
        return number ? scale.toBase(number, suffix) : number;
    }
};
exports.default = bytesFormatter;
//# sourceMappingURL=bytes.js.map