"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const pattern_regexp_utils_1 = require("../utils/pattern-regexp-utils");
const number_to_formatted_number_1 = __importDefault(require("../format/number-to-formatted-number/number-to-formatted-number"));
const currencySymbolsMap = {
    EUR: '€',
    USD: '$',
    XCD: 'EC$',
    AUD: 'A$',
    INR: '₹',
    BRL: 'R$',
    CAD: 'CA$',
    XAF: 'FCFA',
    CNY: 'CN¥',
    NZD: 'NZ$',
    XPF: 'CFPF',
    GBP: '£',
    HKD: 'HK$',
    ILS: '₪',
    JPY: '¥',
    KRW: '₩',
    XOF: 'CFA',
    MXN: 'MX$',
    TWD: 'NT$',
    VND: '₫',
};
const currencyFormatter = {
    name: 'currency',
    regexps: {
        format: /(\$)/,
    },
    format: (number, pattern, options) => {
        var _a;
        const currencyFromOptions = (_a = options.currency) === null || _a === void 0 ? void 0 : _a.toUpperCase();
        const localizedCurrencySymbol = currencySymbolsMap[currencyFromOptions] || currencyFromOptions || '';
        const patternWithEscapedCurrencySymbol = pattern_regexp_utils_1.patternReplace(pattern, /\$/, `'ɵcurrencyɵ'`);
        const formatResult = number_to_formatted_number_1.default(number, patternWithEscapedCurrencySymbol, options);
        return formatResult.replace('ɵcurrencyɵ', _ => localizedCurrencySymbol);
    },
};
exports.default = currencyFormatter;
//# sourceMappingURL=currency.js.map