"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const is_nan_number_1 = __importDefault(require("../../core/utils/is-nan-number"));
const is_finite_number_1 = __importDefault(require("../../core/utils/is-finite-number"));
const pattern_regexp_utils_1 = require("../utils/pattern-regexp-utils");
const multiply_by_power_of_ten_1 = __importDefault(require("../../core/utils/multiply-by-power-of-ten"));
const split_string_in_two_parts_1 = __importDefault(require("../../core/utils/split-string-in-two-parts"));
const formatted_string_to_number_1 = __importDefault(require("../../formatter/parse/utils/formatted-string-to-number"));
const number_to_formatted_number_1 = __importDefault(require("../../formatter/format/number-to-formatted-number/number-to-formatted-number"));
const exponentialFormatter = {
    name: 'exponential',
    regexps: {
        format: /[eE][+-][0-9]+/,
        unformat: /[eE][+-][0-9]+/,
    },
    format: (number, pattern, options) => {
        const exponential = typeof number === 'number' && !is_nan_number_1.default(number) ? number.toExponential() : '0e+0';
        const parts = split_string_in_two_parts_1.default(exponential, 'e');
        const patternWithoutExponential = pattern_regexp_utils_1.patternReplace(pattern, /e[+|-]{1}0/i, '');
        const formatResult = number_to_formatted_number_1.default(+parts[0], patternWithoutExponential, options);
        return formatResult + 'e' + parts[1];
    },
    unformat: (string, options) => {
        var _a;
        const value = formatted_string_to_number_1.default(string.replace(/e[+-]{1}[0-9]{1,3}/i, ''), options);
        const powerOfTenExponent = +(((_a = string.match(/e([+-]{1}[0-9]{1,3})/i)) === null || _a === void 0 ? void 0 : _a[1]) || '0');
        return is_finite_number_1.default(value) ? multiply_by_power_of_ten_1.default(value, powerOfTenExponent) : value;
    },
};
exports.default = exponentialFormatter;
//# sourceMappingURL=exponential.js.map