"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const multiply_by_power_of_ten_1 = __importDefault(require("../../core/utils/multiply-by-power-of-ten"));
const pattern_regexp_utils_1 = require("../utils/pattern-regexp-utils");
const formatted_string_to_number_1 = __importDefault(require("../../formatter/parse/utils/formatted-string-to-number"));
const number_to_formatted_number_1 = __importDefault(require("../../formatter/format/number-to-formatted-number/number-to-formatted-number"));
const percentageFormatter = {
    name: 'percentage',
    regexps: {
        format: /%!?/,
        unformat: /%/,
    },
    format: (number, pattern, options) => {
        const hasNotScalePercentageSymbolInPattern = pattern_regexp_utils_1.patternIncludes(pattern, '%!');
        const scaledValue = options.scalePercentage && !hasNotScalePercentageSymbolInPattern ? multiply_by_power_of_ten_1.default(number, 2) : number;
        const patternWithEscapedPercentage = pattern_regexp_utils_1.patternReplace(pattern, /%!?/, `'ɵ%ɵ'`);
        const formatResult = number_to_formatted_number_1.default(scaledValue, patternWithEscapedPercentage, options);
        return formatResult.replace('ɵ%ɵ', '%');
    },
    unformat: (string, options) => {
        const number = formatted_string_to_number_1.default(string.replace(/\s?%/, ''), options);
        return number && options.scalePercentage ? multiply_by_power_of_ten_1.default(number, -2) : number;
    },
};
exports.default = percentageFormatter;
//# sourceMappingURL=percentage.js.map