"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const is_nil_1 = __importDefault(require("../../core/utils/is-nil"));
const is_function_1 = __importDefault(require("../../core/utils/is-function"));
const is_nan_number_1 = __importDefault(require("../../core/utils/is-nan-number"));
const resolve_format_options_1 = __importDefault(require("../utils/resolve-format-options"));
const formatted_string_to_number_1 = __importDefault(require("./utils/formatted-string-to-number"));
const getUnformatFunctionIfMatch = (input, resolvedOptions) => {
    for (const formatter of resolvedOptions.formatters) {
        const matcher = formatter.regexps.unformat;
        if (!matcher)
            continue;
        const matcherResult = is_function_1.default(matcher) ? matcher(input, resolvedOptions) : !!input.match(matcher);
        if (matcherResult)
            return formatter.unformat;
    }
};
const parse = (input, options) => {
    const resolvedOptions = resolve_format_options_1.default(options);
    let value;
    if (is_nil_1.default(input) || is_nan_number_1.default(input)) {
        value = null;
    }
    else if (typeof input === 'number') {
        // Handles negative zero
        value = input === 0 ? 0 : input;
    }
    else if (typeof input === 'string') {
        if (resolvedOptions.zeroFormat && input === resolvedOptions.zeroFormat) {
            value = 0;
        }
        else if (resolvedOptions.nullFormat && input === resolvedOptions.nullFormat) {
            value = null;
        }
        else {
            const unformatFunctionFromFormatters = getUnformatFunctionIfMatch(input, resolvedOptions);
            const unformatFunction = unformatFunctionFromFormatters || formatted_string_to_number_1.default;
            value = unformatFunction(input, resolvedOptions);
        }
    }
    else {
        const result = +input;
        value = result === 0 ? result : (result || null);
    }
    return value;
};
exports.default = parse;
//# sourceMappingURL=parse.js.map