"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const log_10_1 = __importDefault(require("../../../core/utils/log-10"));
const to_object_1 = __importDefault(require("../../../core/utils/to-object"));
const escape_regex_string_1 = __importDefault(require("../../../core/utils/escape-regex-string"));
const multiply_by_power_of_ten_1 = __importDefault(require("../../../core/utils/multiply-by-power-of-ten"));
const create_unit_scale_from_locale_abbreviations_1 = __importDefault(require("../../utils/create-unit-scale-from-locale-abbreviations"));
const replaceNumeralSystemWithLatinNumbers = (numericStringWithExtraInfo, numeralSystemMap) => {
    if (!numeralSystemMap || numeralSystemMap.length !== 10)
        return numericStringWithExtraInfo;
    const numericStringLength = numericStringWithExtraInfo.length;
    const numeralSystemToLatinSystemMap = to_object_1.default(numeralSystemMap, (digit, digitIndex) => [digit.replace(/\u200e/g, ''), '' + digitIndex]);
    let output = '';
    for (let numericStringIndex = 0; numericStringIndex < numericStringLength; numericStringIndex++) {
        const char = numericStringWithExtraInfo[numericStringIndex];
        output += numeralSystemToLatinSystemMap[char] || char;
    }
    return output;
};
const getScalingFactorFromAbbreviations = (stringOriginal, options) => {
    var _a;
    const scale = create_unit_scale_from_locale_abbreviations_1.default((_a = options.locale) === null || _a === void 0 ? void 0 : _a.abbreviations);
    const abbreviationsSortedByLengthDesc = Object.keys(scale.scaleDefinition.scale).sort((a, b) => b.length - a.length);
    let abbreviationScalingFactor = 1;
    for (const abbreviation of abbreviationsSortedByLengthDesc) {
        const scapedAbbreviationForRegex = escape_regex_string_1.default(abbreviation);
        const regexp = new RegExp('[^a-zA-Z]'
            + `(${scapedAbbreviationForRegex})|(${scapedAbbreviationForRegex.replace(/\u200e/g, '')})`
            + '(?:\\)(?:\\))?)?$');
        if (stringOriginal.match(regexp)) {
            abbreviationScalingFactor = scale.toBase(abbreviationScalingFactor, abbreviation);
            break;
        }
    }
    return abbreviationScalingFactor;
};
// unformats numbers separators, decimals places, signs, abbreviations
const formattedStringToNumber = (inputString, options) => {
    var _a;
    const locale = options.locale;
    const stringOriginal = inputString;
    let value;
    // Replace special digits with latin digits
    const stringWithLatinDigits = replaceNumeralSystemWithLatinNumbers(inputString, (_a = options.locale) === null || _a === void 0 ? void 0 : _a.numeralSystem);
    if (options.zeroFormat && stringWithLatinDigits === options.zeroFormat) {
        value = 0;
    }
    else if (options.nullFormat && stringWithLatinDigits === options.nullFormat || !stringWithLatinDigits.replace(/[^0-9]+/g, '').length) {
        value = null;
    }
    else {
        // Replaces the locale decimal delimiter with a dot (.)
        const decimalDelimiterFromLocale = locale.delimiters.decimal;
        const stringWithDotDecimalDelimiter = decimalDelimiterFromLocale === '.'
            ? stringWithLatinDigits
            : stringWithLatinDigits.replace(/\./g, '').replace(decimalDelimiterFromLocale, '.');
        // Determines the scaling factor from the abbreviations (if has abbreviations)
        const abbreviationScalingFactor = getScalingFactorFromAbbreviations(stringOriginal, options);
        // Check for negative number
        const negativeFactor = (stringWithDotDecimalDelimiter.split('-').length
            + Math.min(stringWithDotDecimalDelimiter.split('(').length - 1, stringWithDotDecimalDelimiter.split(')').length - 1)) % 2 ? 1 : -1;
        // Remove non numbers
        const numberAsString = stringWithDotDecimalDelimiter.replace(/[^0-9.]+/g, '');
        value = negativeFactor * multiply_by_power_of_ten_1.default(+numberAsString, log_10_1.default(abbreviationScalingFactor));
    }
    return value;
};
exports.default = formattedStringToNumber;
//# sourceMappingURL=formatted-string-to-number.js.map