"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const en_1 = __importDefault(require("../../locale/en"));
const merge_1 = __importDefault(require("../../core/utils/merge"));
const is_object_1 = __importDefault(require("../../core/utils/is-object"));
const is_string_1 = __importDefault(require("../../core/utils/is-string"));
const is_function_1 = __importDefault(require("../../core/utils/is-function"));
const truncate_number_1 = __importDefault(require("../../core/utils/truncate-number"));
const built_in_formatters_1 = __importDefault(require("../constants/built-in-formatters"));
const round_half_away_from_zero_1 = __importDefault(require("../../core/utils/round-half-away-from-zero"));
const areDelimitersValid = (delimiters) => {
    return !!(delimiters === null || delimiters === void 0 ? void 0 : delimiters.decimal)
        && is_string_1.default(delimiters === null || delimiters === void 0 ? void 0 : delimiters.thousands)
        && delimiters.decimal !== delimiters.thousands;
};
const resolveOptionsLocale = (optionsLocale) => {
    const defaultLocale = en_1.default;
    if (!is_object_1.default(optionsLocale))
        return defaultLocale;
    return merge_1.default(optionsLocale, {
        delimiters: areDelimitersValid(optionsLocale.delimiters) ? optionsLocale.delimiters : defaultLocale.delimiters,
        abbreviations: optionsLocale.abbreviations || defaultLocale.abbreviations,
        ordinal: optionsLocale.ordinal || defaultLocale.ordinal,
    });
};
const resolveRoundingOption = (roundingOption) => {
    switch (roundingOption) {
        case 'ceil': return Math.ceil;
        case 'floor': return Math.floor;
        case 'truncate': return truncate_number_1.default;
        case 'half-up': return Math.round;
        case 'half-away-from-zero': return round_half_away_from_zero_1.default;
        default: return is_function_1.default(roundingOption) ? roundingOption : round_half_away_from_zero_1.default;
    }
};
const resolveOptionsFormatters = (optionsFormatters) => {
    if (!optionsFormatters)
        return built_in_formatters_1.default;
    return is_function_1.default(optionsFormatters)
        ? optionsFormatters(built_in_formatters_1.default)
        : [...optionsFormatters, ...built_in_formatters_1.default];
};
const resolveFormatOptions = (formatOptions) => {
    var _a, _b;
    const options = formatOptions || {};
    const resolvedRoundingFunction = resolveRoundingOption(options.rounding);
    const resolvedLocale = resolveOptionsLocale(options.locale);
    const resolvedFormatters = resolveOptionsFormatters(options.formatters);
    return {
        defaultPattern: options.defaultPattern || '0,0.##########',
        nullFormat: options.nullFormat || '',
        nanFormat: options.nanFormat,
        zeroFormat: options.zeroFormat,
        locale: resolvedLocale,
        rounding: resolvedRoundingFunction,
        type: options.type,
        scalePercentage: (_a = options.scalePercentage) !== null && _a !== void 0 ? _a : true,
        trim: (_b = options.trim) !== null && _b !== void 0 ? _b : true,
        formatters: resolvedFormatters,
        currency: options.currency,
        negativeZero: !!options.negativeZero,
    };
};
exports.default = resolveFormatOptions;
//# sourceMappingURL=resolve-format-options.js.map